@@ -1,7 +1,8 @@
 import time
+import threading
 import unittest
 
-from pebble.pebble import TimeoutError
+from pebble.pebble import TimeoutError, SerializingError
 from pebble.decorators import asynchronous, concurrent
 
 
@@ -10,6 +11,14 @@ _results = 0
 _exception = None
 
 
+class UnserializeableError(Exception):
+    def __init__(self):
+        self.lock = threading.Lock()  # unpickleable
+
+    def __str__(self):
+        return "BOOM!"
+
+
 def callback(task_id, results):
     global _task_id
     global _results
@@ -82,6 +91,16 @@ def cjob_timeout():
     return 1
 
 
+@concurrent
+def cjob_unserializeable():
+    return threading.Lock()
+
+
+@concurrent
+def cjob_unserializeable_error():
+    raise UnserializeableError()
+
+
 class TestPebbleDecorators(unittest.TestCase):
     def setUp(self):
         global _task_id
@@ -195,10 +214,6 @@ class TestPebbleDecorators(unittest.TestCase):
     def test_concurrent_task_error(self):
         """Test that an exception in a concurrent task is raised by get()."""
         task = cjob_error(1, 1)
-        try:
-            task.get()
-        except:
-            pass
         self.assertRaises(Exception, task.get)
 
     def test_concurrent_task_error_callback(self):
@@ -239,6 +254,21 @@ class TestPebbleDecorators(unittest.TestCase):
         task = cjob_timeout()
         self.assertEqual(task.get(), 1)
 
+    def test_concurrent_unserializable(self):
+        """PicklingError is returned if results are not serializeable."""
+        task = cjob_unserializeable()
+        try:  # Python 2
+            from cPickle import PicklingError
+            self.assertRaises(PicklingError, task.get)
+        except ImportError:  # Python 3
+            from pickle import PicklingError
+            self.assertRaises(PicklingError, task.get)
+
+    def test_concurrent_unserializable_error(self):
+        """SerializingError is returned if exception is not serializeable."""
+        task = cjob_unserializeable_error()
+        self.assertRaises(SerializingError, task.get)
+
 
 if __name__ == "__main__":
     unittest.main()
